@@ -1,13 +1,10 @@
 ## To be cached by .onLoad()
-FutureRegistry <- NULL
-
 .onLoad <- function(libname, pkgname) {
-  ## Import private functions from 'future'
-  FutureRegistry <<- import_future("FutureRegistry")
+  import_future_functions()
   
-  debug <- getOption("future.debug", FALSE)
+  debug <- isTRUE(getOption("future.debug"))
   
-  inRCmdCheck <- import_future("inRCmdCheck")
+  inRCmdCheck <- import_parallelly("inRCmdCheck")
   if (inRCmdCheck()) {
     ## Don't write to current working directory when running R CMD check.
     path <- Sys.getenv("R_FUTURE_CACHE_PATH", NA_character_)
